<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Zadejte repozitář APT, který si přejete použít:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>Repozitáře MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Vybrat nejrychlejší repozitář MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Repozitáře Debianu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Vybrat nejrychlejší repozitář Debianu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Zvláštní zdroje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Obnovit původní zdroje APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="556"/>
        <location filename="../mainwindow.cpp" line="928"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="557"/>
        <location filename="../mainwindow.cpp" line="932"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Váš výběr bude zaveden po aktualizaci zdrojů.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Lists</source>
        <translation>Seznamy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Zdroje (označené zdroje jsou aktivní)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../mainwindow.cpp" line="810"/>
        <location filename="../mainwindow.cpp" line="829"/>
        <location filename="../mainwindow.cpp" line="842"/>
        <location filename="../mainwindow.cpp" line="849"/>
        <location filename="../mainwindow.cpp" line="865"/>
        <location filename="../mainwindow.cpp" line="872"/>
        <location filename="../mainwindow.cpp" line="1007"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <source>Could not change the repo.</source>
        <translation>Změna repozitáře se nezdařila.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>Please wait...</source>
        <translation>Prosím vyčkejte...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>About %1</source>
        <translation>O programu %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program pro výběr předvolených repozitářů APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="672"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Máte vybraný MX Testovací repozitář. Není doporučené nechat ho povolený, nebo z něj aktualizovat všechny balíky.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="707"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Bezpečnější volba je instalovat balíčky samostatně, pomocí MX instalátoru softvéru.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="744"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Zadejte repozitář APT a zdroje, které si přejete použít:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>Příkaz netselect-apt nemohl nalézt nejrychlejší repozitář.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Could not detect fastest repo.</source>
        <translation>Nebylo možné nalézt nejrychlejší repozitář.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Nelze zjistit zda tato aplikace poběží pod antiX nebo MX Linux.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>MX version not detected or out of range: </source>
        <translation>Verze MX nezjištěna nebo je mimo povolené meze: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>Could not download original APT files.</source>
        <translation>Není možné stáhnout původní APT soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Nepovedlo se rozbalit stažený soubor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="915"/>
        <source>Enabling AHS</source>
        <translation>Povolování AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="915"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Používáte repozitář AHS (Advanced Hardware Stack)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="929"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Původní APT zdroje byly obnoveny do původního stavu. Uživatelsky přidané zdroje do /etc/apt/sources.list.d/ nebyly dotčeny.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Při pokusu o zápis souboru: %1 se vyskytla chyba. Prosím zkontrolujte zda máte dostatek místa na disku.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Tento program musíte spustit s oprávněním správce.</translation>
    </message>
</context>
</TS>
